/* $Id: decrypt.c,v 1.9 2008/11/24 23:31:54 tm Exp $
 *
 * PDFlib PLOP: PDF Linearization, Optimization, Protection
 * decryption sample
 *
 */

#include <stdio.h>

#include "ploplib.h"

int
main(void)
{
    PLOP *plop;
    /* parameters for the input document */
    const char *in_filename = "PLOP-datasheet-encrypted.pdf";
    const char *in_password = "DEMO";

    /* parameters for the output document */
    const char *out_filename = "PLOP-datasheet-decrypted.pdf";
    const char *out_master = "";
    const char *out_user = "";
    const char *permissions = "";

    /* This is where input files live. Adjust as necessary. */
    char *searchpath = "../data";

    /* create a new PLOP object */
    if ((plop = PLOP_new()) == (PLOP *) 0)
    {
	printf("Couldn't create PLOP object (out of memory)!\n");
	return(2);
    }

    PLOP_TRY(plop) {
	int doc;
	char optlist[1024];

	sprintf(optlist, "searchpath={%s}", searchpath);
	PLOP_set_option(plop, optlist);

	/* open protected input file with the password */
	sprintf(optlist, "password {%s} ", in_password);
	if ((doc = PLOP_open_document(plop, in_filename, 0, optlist)) == -1)
	{
	    printf("Error: %s\n", PLOP_get_errmsg(plop));
	    PLOP_delete(plop);
	    return(2);
	}

	/* create the output file */
	sprintf(optlist, "masterpassword {%s} userpassword {%s} "
	    "permissions {%s}",
	    out_master, out_user, permissions);

	if (PLOP_create_file(plop, out_filename, 0, optlist)== -1)
	{
	    printf("Error: %s\n", PLOP_get_errmsg(plop));
	    PLOP_delete(plop);
	    return(2);
	}

	/* close input and output files */
	PLOP_close_document(plop, doc);
    }

    PLOP_CATCH(plop) {
	printf("PLOP exception occurred in decrypt:\n");
	printf("[%d] %s: %s\n", PLOP_get_errnum(plop),
		PLOP_get_apiname(plop), PLOP_get_errmsg(plop));
	PLOP_delete(plop);
	return(2);
    }

    /* delete the PLOP object */
    PLOP_delete(plop);

    return(0);
}
