/* $Id: linearize.c,v 1.8 2008/11/24 23:31:54 tm Exp $
 *
 * PDFlib PLOP: PDF Linearization, Optimization, Protection
 * linearization sample
 *
 */

#include <stdio.h>

#include "ploplib.h"

int
main(void)
{
    PLOP *plop;
    /* input document */
    const char *in_filename = "PLOP-datasheet.pdf";

    /* output document */
    const char *out_filename = "PLOP-datasheet-linearized.pdf";

    /* This is where input files live. Adjust as necessary. */
    char *searchpath = "../data";

    /* create a new PLOP object */
    if ((plop = PLOP_new()) == (PLOP *) 0)
    {
	printf("Couldn't create PLOP object (out of memory)!\n");
	return(2);
    }

    PLOP_TRY(plop) {
	int doc;
	char optlist[1024];

	sprintf(optlist, "searchpath={%s}", searchpath);
	PLOP_set_option(plop, optlist);

	/* open input file */
	if ((doc = PLOP_open_document(plop, in_filename, 0, "")) == -1)
	{
	    printf("Error: %s\n", PLOP_get_errmsg(plop));
	    PLOP_delete(plop);
	    return(2);
	}

	/* create the linearized output file */
	if (PLOP_create_file(plop, out_filename, 0, 
		"linearize docinfo={Author {PDFlib GmbH}}") == -1)
	{
	    printf("Error: %s\n", PLOP_get_errmsg(plop));
	    PLOP_delete(plop);
	    return(2);
	}

	/* close input and output files */
	PLOP_close_document(plop, doc);
    }

    PLOP_CATCH(plop) {
	printf("PLOP exception occurred in linearize:\n");
	printf("[%d] %s: %s\n", PLOP_get_errnum(plop),
		PLOP_get_apiname(plop), PLOP_get_errmsg(plop));
	PLOP_delete(plop);
	return(2);
    }

    /* delete the PLOP object */
    PLOP_delete(plop);

    return(0);
}
