/* $Id: EncryptServlet.java,v 1.1 2011/03/08 11:51:15 stm Exp $
 *
 * PDFlib PLOP: PDF Linearization, Optimization, Protection
 * encryption sample
 */

import java.io.PrintWriter;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

import com.pdflib.PLOPException;
import com.pdflib.plop;

public class EncryptServlet extends HttpServlet {
    private static final long serialVersionUID = 421239375938862931L;

    public void service(HttpServletRequest request, HttpServletResponse response)
            throws ServletException {
        plop plop = null;

        try {
            /*
             * Set up searchpath for the required data.
             */
            final ServletContext context = getServletContext();
            final String searchpath = context.getRealPath("/WEB-INF/data");

            /*
             * Catch problems that application data cannot be accessed.
             */
            if (searchpath == null) {
                throw new ServletException(
                        "Error: Unable to access application data (WAR file not unpacked?)");
            }
            
            /* parameters for the input document */
            final String in_filename = "PLOP-datasheet.pdf";
            final String in_password = "";
            
            /* parameters for the output document */
            final String enc_document_basename = "PLOP-datasheet-encrypted.pdf";
            final String out_filename = context.getRealPath("/") + enc_document_basename   ;
            final String out_master = "DEMO";
            final String out_user = "demo";
            final String permissions = "";
            int doc;

            plop = new plop();

            plop.set_option("searchpath={" + searchpath + "}");
            
            /* open unprotected input file without any password */
            String optlist = "password {" + in_password + "} ";
            if ((doc = plop.open_document(in_filename, optlist)) == -1) {
                throw new Exception("Error: " + plop.get_errmsg());
            }

            /* create the output file with a password */
            optlist = "masterpassword {" + out_master + "} userpassword {"
                    + out_user + "} permissions {" + permissions + "}";
            if (plop.create_file(out_filename, optlist) == -1) {
                throw new Exception("Error: " + plop.get_errmsg());
            }

            response.setContentType("text/html");

            PrintWriter writer = response.getWriter();
            writer.println("<html><head><title>Successfully encrypted input document</title></head><body>");
            writer.println("The input file was successfully encrypted. The encrypted copy can be opened with the password &quot;" + out_user + "&quot;.<br>");
            writer.println("<a href='" + enc_document_basename + "'>Click here</a> to open the encrypted copy.<br>");
            writer.println("Back to <a href='index.html'>start page</a>.");
            writer.println("</body>");
            writer.close();

            /* close input and output files */
            plop.close_document(doc);
        }
        catch (PLOPException e) {
            throw new ServletException("PLOP exception occurred in "
                    + getClass().getName(), e);
        }
        catch (Exception e) {
            throw new ServletException("Exception occurred in "
                    + getClass().getName(), e);
        }
        finally {
            /* delete the PLOP object */
            if (plop != null)
                plop.delete();
        }
    }
}
