/* $Id: SignServlet.java,v 1.1 2011/03/08 11:51:15 stm Exp $
 *
 * PDFlib PLOP: PDF Linearization, Optimization, Protection
 * sample for creating a signed document
 */

import javax.servlet.http.HttpServlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import com.pdflib.PLOPException;
import com.pdflib.plop;

public class SignServlet extends HttpServlet {
    private static final long serialVersionUID = -4446230350807159305L;

    public void service(ServletRequest request, ServletResponse response)
            throws ServletException {
        plop plop = null;

        try {
            /* parameters for the input document */
            final String in_filename = "invoice.pdf";

            /*
             * alternatives for specifying the certificate
             * 
             * Windows Certificate Store (Windows only): "engine=mscapi" +
             * "digitalid={certstore={store=My subject={DEMO PLOP user 2048}}}"
             * PFX certificate from file in search path: "engine=builtin " +
             * "digitalid={filename=demo2048.pfx} " PKCS#12 certificate from
             * file in search path: "engine=builtin " +
             * "digitalid={filename=demo2048.p12} " PKCS#11 certificate
             * "engine=pkcs#11 " + "digitalid={filename=cryptoki.dll} "
             */
            String sign_opts = "sign={" + "appearance={fieldname=Signature1 } "
                    + "engine=builtin " + "digitalid={filename=demo2048.p12} "
                    + "password={demo} " + "reason={I agree to this document} "
                    + "contactinfo={tel (123) 456 789} " + "location=Munich "
                    + "}";

            plop = new plop();
            
            /*
             * Set up searchpath for the required data.
             */
            final ServletContext context = getServletContext();
            final String searchpath = context.getRealPath("/WEB-INF/data");

            /*
             * Catch problems that application data cannot be accessed.
             */
            if (searchpath == null) {
                throw new ServletException(
                        "Error: Unable to access application data (WAR file not unpacked?)");
            }

            /* open unprotected input file without any password */
            String optlist = "searchpath {" + searchpath + "} ";
            plop.set_option(optlist);
            int doc;
            if ((doc = plop.open_document(in_filename, "")) == -1) {
                throw new Exception("Error: " + plop.get_errmsg());
            }

            /* create the output file with a password */
            if (plop.create_file("", sign_opts) == -1) {
                throw new Exception("Error: " + plop.get_errmsg());
            }

            final byte[] buf = plop.get_buffer();

            response.setContentType("application/pdf");
            response.setContentLength(buf.length);

            final ServletOutputStream out = response.getOutputStream();
            out.write(buf);
            out.close();

            /* close input and output files */
            plop.close_document(doc);
        }
        catch (PLOPException e) {
            throw new ServletException("PLOP exception occurred in "
                    + getClass().getName(), e);
        }
        catch (Exception e) {
            throw new ServletException("Exception occurred in "
                    + getClass().getName(), e);
        }
        finally {
            /* delete the PLOP object */
            if (plop != null)
                plop.delete();
        }
    }
}
