#!/usr/bin/perl
# $Id: dumper.pl,v 1.3 2011/02/23 18:44:01 rjs Exp $
#

use plop_pl 4.1

my $doc;

# This is where input files live. Adjust as necessary.
my $searchpath = "../data";

# create a new PLOP object
my $plop = PLOP_new();


if ($#ARGV != 0) {
    die("usage: dumper <filename>\n");
}

eval {
    my ($count, $pcosmode, $plainmetadata);
    my ($objtype, $i, $doc);
    my $docoptlist = "requiredmode=minimum";
    my $globaloptlist = "";
    my $optlist;

    PLOP_set_option($plop, $globaloptlist);

    $optlist = sprintf("searchpath={%s}", $searchpath);
    PLOP_set_option($plop, $optlist);

    if (($doc = PLOP_open_document($plop, $ARGV[0], $docoptlist)) == -1)
    {
	printf("ERROR: %s\n", PLOP_get_errmsg($plop));
	PLOP_delete($plop);
	exit;
    }

    # --------- general information (always available)

    $pcosmode = PLOP_pcos_get_number($plop, $doc, "pcosmode");

    printf("   File name: %s\n", PLOP_pcos_get_string($plop, $doc, "filename"));

    printf(" PDF version: %s\n",
	PLOP_pcos_get_string($plop, $doc, "pdfversionstring"));

    printf("  Encryption: %s\n",
	PLOP_pcos_get_string($plop, $doc, "encrypt/description"));

    printf("   Master pw: %s\n",
	PLOP_pcos_get_number($plop, $doc, "encrypt/master") ? "yes" : "no");

    printf("     User pw: %s\n",
	PLOP_pcos_get_number($plop, $doc, "encrypt/user") ? "yes" : "no");

    printf("Text copying: %s\n",
	PLOP_pcos_get_number($plop, $doc, "encrypt/nocopy") ? "no" : "yes");

    printf("  Linearized: %s\n",
	PLOP_pcos_get_number($plop, $doc, "linearized") ? "yes" : "no");

    if ($pcosmode == 0) {
	printf("Minimum mode: no more information available\n\n");
	PLOP_close_document($plop, $doc);
	PLOP_delete($plop);
	exit;
    }

    # --------- more details (requires at least user password)

    printf("PDF/X status: %s\n", PLOP_pcos_get_string($plop, $doc, "pdfx"));

    printf("PDF/A status: %s\n", PLOP_pcos_get_string($plop, $doc, "pdfa"));

    printf("    XFA data: %s\n",
        PLOP_pcos_get_string($plop, $doc, "type:/Root/AcroForm/XFA") ne "null"
                            ? "yes" : "no");

    printf("  Tagged PDF: %s\n\n",
	PLOP_pcos_get_number($plop, $doc, "tagged") ? "yes" : "no");

    printf("No. of pages: %d\n",
	PLOP_pcos_get_number($plop, $doc, "length:pages"));

    printf(" Page 1 size: width=%g, height=%g\n",
	PLOP_pcos_get_number($plop, $doc, "pages[0]/width"),
	PLOP_pcos_get_number($plop, $doc, "pages[0]/height"));

    $count = PLOP_pcos_get_number($plop, $doc, "length:fonts");
    printf("No. of fonts: %d\n", $count);

    for ($i=0; $i < $count; $i++) {
	if (PLOP_pcos_get_number($plop, $doc, "fonts[$i]/embedded")) {
	    printf("embedded ");
	}
	else {
	    printf("unembedded ");
	}

	printf("%s font ",
	    PLOP_pcos_get_string($plop, $doc, "fonts[$i]/type"));
	printf("%s\n",
	    PLOP_pcos_get_string($plop, $doc, "fonts[$i]/name"));
    }

    printf("\n");

    $plainmetadata =
	PLOP_pcos_get_number($plop, $doc, "encrypt/plainmetadata");

    if ($pcosmode == 1 && !$plainmetadata &&
	( PLOP_pcos_get_number($plop, $doc, "encrypt/nocopy"))) {
	printf("Restricted mode: no more information available\n\n");
	PLOP_close_document($plop, $doc);
	PLOP_delete($plop);
	exit;
    }

    # --------- document info keys and XMP metadata (requires master pw
    # or plaintext metadata)
    #

    $count = PLOP_pcos_get_number($plop, $doc, "length:/Info");

    for ($i=0; $i < $count; $i++) {
	$objtype = PLOP_pcos_get_string($plop, $doc, "type:/Info[$i]");
	printf("%12s: ", PLOP_pcos_get_string($plop, $doc, "/Info[$i].key"));

	# Info entries can be stored as string or name objects
	if ($objtype eq "string" || $objtype eq "name")
	{
	    printf("'%10s'\n",
		    PLOP_pcos_get_string($plop, $doc, "/Info[$i]"));
	}
	else
	{
	    printf("(%s object)\n",
		PLOP_pcos_get_string($plop, $doc, "type:/Info[$i]"));
	}
    }

    printf("\nXMP meta data: ");

    $objtype = PLOP_pcos_get_string($plop, $doc, "type:/Root/Metadata");
    if ($objtype eq "stream") {
	my $contents;

	$contents = PLOP_pcos_get_stream($plop, $doc, "", "/Root/Metadata");
	printf("%d bytes ", length($contents));

	# This demonstrates Unicode conversion 
	$contents = PLOP_convert_to_unicode($plop, "utf8", $contents,
						"outputformat=utf16");
	printf("(%d Unicode characters)\n\n", length($contents)/2);
    }
    else {
	printf("not present\n\n");
    }

    PLOP_close_document($plop, $doc);
};
if ($@) {
    printf("encrypt: PLOP exception occurred:\n");
    printf("$@\n");
    PLOP_delete($plop);
    exit;
}

# delete the PLOP object
PLOP_delete($plop);
