#!/usr/bin/perl
# $Id: insertxmp.pl,v 1.2 2011/02/23 18:44:01 rjs Exp $
#
# PDFlib PLOP: PDF Linearization, Optimization, Protection
# mini sample for inserting XMP metadata in PDF documents
#
#

use plop_pl 4.1

# Directory where files will be searched
my $searchpath = "../data";
# input document
my $in_filename  = "PLOP-datasheet.pdf";
# output document
my $out_filename = "PLOP-datasheet-xmp.pdf";

# Option list for the generated output document.
# Some alternatives for the option list using the supplied XMP samples:
#
# Insert custom metadata for the GWG (Ghent Workgroup)
# Ad Ticket scheme (see http://www.gwg.org/Jobtickets.phtml):
# "metadata={filename=gwg_ad_ticket.xmp validate=xmp2004}"
#
# Insert custom metadata based on Acme's enterprise schema:
# "metadata={filename=acme.xmp}"
#
# Insert a custom "engineering" schema for scanned documents:
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=engineering.xmp}"
#
# Insert a PDF/A extension schema after validating the XMP for PDF/A-1.
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=machine_pdfa1.xmp validate=pdfa1}"
#
my $out_optlist = "metadata={filename=gwg_ad_ticket.xmp}";


# create a new PLOP object
my $plop = PLOP_new();

eval {
    my $doc;
    my $optlist;

    $optlist = "searchpath={$searchpath}";
    PLOP_set_option($plop, $optlist);

    # open input file
    if (($doc = PLOP_open_document($plop, $in_filename, "")) == -1)
    {
	printf("Error: %s", PLOP_get_errmsg($plop));
	PLOP_delete($plop);
	exit;
    };

    # create the output file and add XMP metadata
    if (PLOP_create_file($plop, $out_filename, $out_optlist) == -1)
    {
	printf("Error: %s", PLOP_get_errmsg($plop));
	PLOP_delete($plop);
	exit;
    }

    # close input and output files
    PLOP_close_document($plop, $doc);
};
if ($@) {
    printf("PLOP exception occurred in insertxmp:\n");
    printf("$@\n");
    PLOP_delete($plop);
    exit;
}

# delete the PLOP object
PLOP_delete($plop);
