#!/usr/bin/perl
# $Id: sign.pl,v 1.3 2011/02/24 13:19:14 rjs Exp $
#
# PDFlib PLOP: PDF Linearization, Optimization, Protection
# digital signature sample
#

use plop_pl 4.1

my $doc;
# create a new PLOP object
my $plop = PLOP_new();

# This is where input files live. Adjust as necessary.
my $searchpath = "../data";

if ($#ARGV != 1) {
    die("usage: sign <infile> <outfile>\n" );
}

eval {
    my $optlist;

    # alternatives for specifying the certificate
    #
    # Windows Certificate Store (Windows only):
    #    "engine=mscapi " .
    #    "digitalid={certstore={store=My subject={DEMO PLOP user 2048}}} "
    # PFX certificate from file in search path:
    #    "engine=builtin " .
    #    "digitalid={filename=demo2048.pfx} "
    # PKCS#12 certificate from file in search path:
    #    "engine=builtin " .
    #    "digitalid={filename=demo2048.p12} "
    # PKCS#11 certificate
    #    "engine=pkcs#11 " .
    #    "digitalid={filename=cryptoki.dll} "
    #
    my $sign_opts = "sign={" .
	"appearance={fieldname=Signature1 } " .
        "engine=builtin " .
	"digitalid={filename=demo2048.p12} " .
	"password={demo} " .
	"reason={I agree to this document} " .
	"contactinfo={tel (123) 456 789} " .
	"location=Munich " .
	"}";

    PLOP_set_option($plop, "searchpath={${searchpath}}");

    if (($doc = PLOP_open_document($plop, $ARGV[0], "")) == -1)
    {
	printf("Error: %s\n", PLOP_get_errmsg($plop));
	PLOP_delete($plop);
	exit;
    }

    if (PLOP_create_file($plop, $ARGV[1], $sign_opts) == -1)
    {
	printf("Error: %s\n", PLOP_get_errmsg($plop));
	PLOP_delete($plop);
	exit;
    }

    PLOP_close_document($plop, $doc);
};
if ($@) {
    printf("encrypt: PLOP exception occurred:\n");
    printf("$@\n");
    PLOP_delete($plop);
    exit;
}

# delete the PLOP object
PLOP_delete($plop);
