# PDFlib PLOP: PDF Linearization, Optimization, Protection
# mini sample for inserting XMP metadata in PDF documents
#
# $Id: insertxmp.py,v 1.3 2011/02/24 10:03:15 rjs Exp $
#

# Option list for the generated output document.
# Some alternatives for the option list using the supplied XMP samples:
#
# Insert custom metadata for the GWG (Ghent Workgroup)
# Ad Ticket scheme (see http://www.gwg.org/Jobtickets.phtml):
# "metadata={filename=gwg_ad_ticket.xmp validate=xmp2004}"
#
# Insert custom metadata based on Acme's enterprise schema:
# "metadata={filename=acme.xmp}"
#
# Insert a custom "engineering" schema for scanned documents:
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=engineering.xmp}"
#
# Insert a PDF/A extension schema after validating the XMP for PDF/A-1.
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=machine_pdfa1.xmp validate=pdfa1}"
#

from sys import *
from traceback import *
from plop_py import *

# Directory where files will be searched
searchpath = "../data"
# input document
in_filename  = "PLOP-datasheet.pdf"
# output document
out_filename = "PLOP-datasheet-xmp.pdf"

out_optlist = "metadata={filename=gwg_ad_ticket.xmp}"

# create a new PLOP object
plop = PLOP_new()

try:
    try:
        optlist = "searchpath={%s}" % searchpath
        PLOP_set_option(plop, optlist)

        # open input file
        doc = PLOP_open_document(plop, in_filename, "")
        if (doc == -1):
            raise PLOPException("Error: %s" % PLOP_get_errmsg(plop))

        # create the output file and add XMP metadata
        if (PLOP_create_file(plop, out_filename, out_optlist) == -1):
            raise PLOPException("Error: %s" % PLOP_get_errmsg(plop))

        # close input and output files
        PLOP_close_document(plop, doc)

    except PLOPException:
        print_exc(file=stdout)

except Exception:
    print_exc(file=stdout)

finally:
    PLOP_delete(plop)
